@@ -163,6 +163,12 @@ def infer_sex(
         gt_expr='LGT',
     )
 
+    # Adding chrX het/hom count as another sex check
+    chrx_mt = hl.filter_intervals(mt, [hl.parse_locus_interval('chrX')])
+    chrx_ht = hl.sample_qc(chrx_mt).cols()
+    ht = ht.annotate(chrx_qc=chrx_ht[ht.key].sample_qc)
+    ht = ht.annotate(chrx_r_het_hom_var=ht.chrx_qc.r_het_hom_var)
+
     return ht.checkpoint(out_ht_path, overwrite=True)
 
 
@@ -679,28 +685,28 @@ def compute_hard_filters(
 
     ht = add_filter(
         ht,
-        hl.is_missing(picard_metrics_ht[ht.key].r_contamination)
-        | (
+        hl.is_defined(picard_metrics_ht[ht.key].r_contamination)
+        & (
             picard_metrics_ht[ht.key].r_contamination > cutoffs_d['max_r_contamination']
         ),
         'contamination',
     )
     ht = add_filter(
         ht,
-        hl.is_missing(picard_metrics_ht[ht.key].r_chimera)
-        | (picard_metrics_ht[ht.key].r_chimera > cutoffs_d['max_r_chimera']),
+        hl.is_defined(picard_metrics_ht[ht.key].r_chimera)
+        & (picard_metrics_ht[ht.key].r_chimera > cutoffs_d['max_r_chimera']),
         'chimera',
     )
     ht = add_filter(
         ht,
-        hl.is_missing(picard_metrics_ht[ht.key].r_duplication)
-        | (picard_metrics_ht[ht.key].r_duplication > cutoffs_d['max_r_duplication']),
+        hl.is_defined(picard_metrics_ht[ht.key].r_duplication)
+        & (picard_metrics_ht[ht.key].r_duplication > cutoffs_d['max_r_duplication']),
         'dup_rate',
     )
     ht = add_filter(
         ht,
-        hl.is_missing(picard_metrics_ht[ht.key].median_insert_size)
-        | (
+        hl.is_defined(picard_metrics_ht[ht.key].median_insert_size)
+        & (
             picard_metrics_ht[ht.key].median_insert_size
             < cutoffs_d['min_median_insert_size']
         ),
